==> autotrain-advanced-0.7.91.tar.gz: autotrain-advanced-0.7.91/src/autotrain/trainers/object_detection/params.py <==
from typing import Optional

from pydantic import Field

from autotrain.trainers.common import AutoTrainParams


class ObjectDetectionParams(AutoTrainParams):
    data_path: str = Field(None, title="Data path")
    model: str = Field("google/vit-base-patch16-224", title="Model name")
    username: Optional[str] = Field(None, title="Hugging Face Username")
    lr: float = Field(5e-5, title="Learning rate")
    epochs: int = Field(3, title="Number of training epochs")
    batch_size: int = Field(8, title="Training batch size")
    warmup_ratio: float = Field(0.1, title="Warmup proportion")
    gradient_accumulation: int = Field(1, title="Gradient accumulation steps")
    optimizer: str = Field("adamw_torch", title="Optimizer")
    scheduler: str = Field("linear", title="Scheduler")
    weight_decay: float = Field(0.0, title="Weight decay")
    max_grad_norm: float = Field(1.0, title="Max gradient norm")
    seed: int = Field(42, title="Seed")
    train_split: str = Field("train", title="Train split")
    valid_split: Optional[str] = Field(None, title="Validation split")
    logging_steps: int = Field(-1, title="Logging steps")
    project_name: str = Field("project-name", title="Output directory")
    auto_find_batch_size: bool = Field(False, title="Auto find batch size")
    mixed_precision: Optional[str] = Field(None, title="fp16, bf16, or None")
    save_total_limit: int = Field(1, title="Save total limit")
    token: Optional[str] = Field(None, title="Hub Token")
    push_to_hub: bool = Field(False, title="Push to hub")
    evaluation_strategy: str = Field("epoch", title="Evaluation strategy")
    image_column: str = Field("image", title="Image column")
    objects_column: str = Field("objects", title="Target column")
    log: str = Field("none", title="Logging using experiment tracking")
    image_square_size: Optional[int] = Field(
        600, title="Image longest size will be resized to this value, then image will be padded to square."
    )

==> autotrain-advanced-0.7.126.tar.gz: autotrain-advanced-0.7.126/src/autotrain/trainers/object_detection/params.py <==
from typing import Optional

from pydantic import Field

from autotrain.trainers.common import AutoTrainParams


class ObjectDetectionParams(AutoTrainParams):
    data_path: str = Field(None, title="Data path")
    model: str = Field("google/vit-base-patch16-224", title="Model name")
    username: Optional[str] = Field(None, title="Hugging Face Username")
    lr: float = Field(5e-5, title="Learning rate")
    epochs: int = Field(3, title="Number of training epochs")
    batch_size: int = Field(8, title="Training batch size")
    warmup_ratio: float = Field(0.1, title="Warmup proportion")
    gradient_accumulation: int = Field(1, title="Gradient accumulation steps")
    optimizer: str = Field("adamw_torch", title="Optimizer")
    scheduler: str = Field("linear", title="Scheduler")
    weight_decay: float = Field(0.0, title="Weight decay")
    max_grad_norm: float = Field(1.0, title="Max gradient norm")
    seed: int = Field(42, title="Seed")
    train_split: str = Field("train", title="Train split")
    valid_split: Optional[str] = Field(None, title="Validation split")
    logging_steps: int = Field(-1, title="Logging steps")
    project_name: str = Field("project-name", title="Output directory")
    auto_find_batch_size: bool = Field(False, title="Auto find batch size")
    mixed_precision: Optional[str] = Field(None, title="fp16, bf16, or None")
    save_total_limit: int = Field(1, title="Save total limit")
    token: Optional[str] = Field(None, title="Hub Token")
    push_to_hub: bool = Field(False, title="Push to hub")
    eval_strategy: str = Field("epoch", title="Evaluation strategy")
    image_column: str = Field("image", title="Image column")
    objects_column: str = Field("objects", title="Target column")
    log: str = Field("none", title="Logging using experiment tracking")
    image_square_size: Optional[int] = Field(
        600, title="Image longest size will be resized to this value, then image will be padded to square."
    )
    early_stopping_patience: int = Field(5, title="Early stopping patience")
    early_stopping_threshold: float = Field(0.01, title="Early stopping threshold")
